@@ -1,8 +1,8 @@
 package asset
 
 import (
-	c "github.com/achannarasappa/ticker/internal/common"
-	"github.com/achannarasappa/ticker/internal/currency"
+	c "github.com/achannarasappa/ticker/v4/internal/common"
+	"github.com/achannarasappa/ticker/v4/internal/currency"
 )
 
 // AggregatedLot represents a cost basis lot of an asset grouped by symbol
@@ -46,6 +46,7 @@ func GetAssets(ctx c.Context, assetGroupQuote c.AssetGroupQuote) ([]c.Asset, Hol
 			Holding:       holding,
 			QuotePrice:    convertAssetQuotePriceCurrency(currencyRateByUse, assetQuote.QuotePrice),
 			QuoteExtended: convertAssetQuoteExtendedCurrency(currencyRateByUse, assetQuote.QuoteExtended),
+			QuoteFutures:  assetQuote.QuoteFutures,
 			QuoteSource:   assetQuote.QuoteSource,
 			Exchange:      assetQuote.Exchange,
 			Meta: c.Meta{
