@@ -16,10 +16,10 @@ import (
 	"github.com/spf13/afero"
 	"github.com/spf13/cobra"
 
-	"github.com/achannarasappa/ticker/internal/cli"
-	. "github.com/achannarasappa/ticker/internal/cli"
-	c "github.com/achannarasappa/ticker/internal/common"
-	httpMocks "github.com/achannarasappa/ticker/test/http"
+	"github.com/achannarasappa/ticker/v4/internal/cli"
+	. "github.com/achannarasappa/ticker/v4/internal/cli"
+	c "github.com/achannarasappa/ticker/v4/internal/common"
+	httpMocks "github.com/achannarasappa/ticker/v4/test/http"
 )
 
 func getStdout(fn func()) string {
@@ -252,10 +252,12 @@ var _ = Describe("Cli", func() {
 					InputOptions: cli.Options{},
 					InputConfigFileContents: strings.Join([]string{
 						"watchlist:",
-						"  - TSLA",        // yahoo finance
-						"  - ETHEREUM.CG", // coingecko
-						"  - BITCOIN.CC",  // coincap
-						"  - SOL.X",       // ticker
+						"  - TSLA",               // yahoo finance
+						"  - ETHEREUM.CG",        // coingecko
+						"  - BITCOIN.CC",         // coincap
+						"  - ADA.CB",             // coinbase
+						"  - BIT-31JAN25-CDE.CB", // coinbase futures
+						"  - SOL.X",              // ticker
 					}, "\n"),
 					AssertionErr: BeNil(),
 					AssertionCtx: g.MatchFields(g.IgnoreExtras, g.Fields{
@@ -283,6 +285,13 @@ var _ = Describe("Cli", func() {
 										}),
 										"Source": Equal(c.QuoteSourceCoinCap),
 									}),
+									"5": g.MatchFields(g.IgnoreExtras, g.Fields{
+										"Symbols": g.MatchAllElementsWithIndex(g.IndexIdentity, g.Elements{
+											"0": Equal("ADA-USD"),
+											"1": Equal("BIT-31JAN25-CDE"),
+										}),
+										"Source": Equal(c.QuoteSourceCoinbase),
+									}),
 								}),
 							}),
 						}),
