@@ -4,7 +4,7 @@ import (
 	"math"
 	"strconv"
 
-	c "github.com/achannarasappa/ticker/internal/common"
+	c "github.com/achannarasappa/ticker/v4/internal/common"
 )
 
 func getPrecision(f float64) int {
