@@ -205,6 +205,56 @@ func MockResponseCoincapQuotes() {
 
 }
 
+func MockResponseCoinbaseQuotes() {
+	responseFixture := `{
+		"products": [
+			{
+				"product_id": "ADA-31JAN25-CDE",
+				"price": "97345",
+				"price_percentage_change_24h": "-3.14412218297597",
+				"volume_24h": "93744",
+				"base_name": "",
+				"status": "",
+				"product_type": "FUTURE",
+				"quote_currency_id": "USD",
+				"fcm_trading_session_details": {
+					"is_session_open": true
+				},
+				"base_display_symbol": "",
+				"product_venue": "FCM",
+				"future_product_details": {
+					"venue": "cde",
+					"contract_code": "ADA",
+					"contract_expiry": "2025-01-31T16:00:00Z",
+					"contract_root_unit": "ADA",
+					"group_description": "Cardano Futures",
+					"contract_expiry_timezone": "Europe/London"
+				}
+			},
+			{
+				"base_display_symbol": "ADA",
+				"product_type": "SPOT",
+				"product_id": "ADA-USD",
+				"base_name": "Cardano",
+				"price": "50000.00",
+				"price_percentage_change_24h": "2.0408163265306123",
+				"volume_24h": "1500.50",
+				"display_name": "Cardano",
+				"status": "",
+				"quote_currency_id": "USD",
+				"product_venue": "CBE"
+			}
+		]
+	}`
+	responseURL := `=~\/api\/v3\/brokerage\/market\/products.*`
+	httpmock.RegisterResponder("GET", responseURL, func(_ *http.Request) (*http.Response, error) {
+		resp := httpmock.NewStringResponse(200, responseFixture)
+		resp.Header.Set("Content-Type", "application/json")
+
+		return resp, nil
+	})
+}
+
 func MockTickerSymbols() {
 	responseFixture := `"ADA.X","cardano","cg"
 "ALGO.X","algorand","cg"
